.. _mailing_lists:

=============
Mailing Lists
=============

There is a mailing list for discussing ASE:

* ase-users_

The mailing lists below are of interest for active ASE developers only:

* ase-developers_
* ase-svncheckins_

.. _ase-developers: https://listserv.fysik.dtu.dk/mailman/listinfo/
                    ase-developers
.. _ase-svncheckins: https://listserv.fysik.dtu.dk/mailman/listinfo/
                     ase-svncheckins
.. _ase-users: https://listserv.fysik.dtu.dk/mailman/listinfo/ase-users


.. _irc:

Internet Relay Chat
===================

We have the IRC channel ``#ase`` on FreeNode.  Please join us if you
have any questions. For easy access, you can use this webclient_.

.. _webclient: http://webchat.freenode.net/?randomnick=0&channels=ase
